#!/bin/sh

# Set environment variable
source ./setenv.sh

J2EE_BIN="/opt/FJSVj2ee/bin"
ISAS_BIN="/opt/FJSVisas/bin"
JMX_BIN="/opt/FJSVisjmx/bin"
OD_BIN="/opt/FJSVod/bin"
PRM_DIR="../parampkg/"
ERROR_MSG=""
errflg=0


# Apache definition update
$ISAS_BIN/isihsconfigset
if [ $? != 0 ]; then
   ERROR_MSG=$ERROR_MSG"[isihsconfigset]"
   errflg=1
fi

# isj2eeadmin check
if [ -f /opt/FJSVj2ee/bin/isj2eeadmin ]; then

    # JXM start
    $JMX_BIN/isjmxstart
    if [ $? != 0 ]; then
        echo "[IAPS]JXM service couldn't be started"
        exit 1
    fi

    # OD start
    $OD_BIN/OD_start
    if [ $? != 0 ]; then
        echo "[IAPS]OD service couldn't be startd"
        exit 1
    fi

    # IJServer definition update
    if [ "$J2ee_IjserverDefinition" != "" ] ; then
        $J2EE_BIN/isj2eeadmin ijserver -o -f "$PRM_DIR$J2ee_IjserverDefinition"
        if [ $? != 0 ]; then
            ERROR_MSG=$ERROR_MSG"[IjserverDefinition]"
            errflg=1
        fi
    fi

    # J2EE System definition update
    if [ "$J2ee_SystemDefinition" != "" ] ; then
        $J2EE_BIN/isj2eeadmin system -o -f "$PRM_DIR$J2ee_SystemDefinition"
        if [ $? != 0 ]; then
            ERROR_MSG=$ERROR_MSG"[SystemDefinition]"
            errflg=1
        fi
    fi

    # J2EE Resource definition update
    if [ "$J2ee_ResourceDefinition" != "" ] ; then
        $J2EE_BIN/isj2eeadmin resource -o -f "$PRM_DIR$J2ee_ResourceDefinition"
        if [ $? != 0 ]; then
            ERROR_MSG=$ERROR_MSG"[ResourceDefinition]"
            errflg=1
        fi
    fi

    # Web Sever Connector definition update
    if [ "$J2ee_ServiceDefinition" != "" ] ; then
        $J2EE_BIN/isj2eeadmin service -o -f "$PRM_DIR$J2ee_ServiceDefinition"
        if [ $? != 0 ]; then
            ERROR_MSG=$ERROR_MSG"[ServiceDefinition]"
            errflg=1
	fi
    fi

    # OD stop
    $OD_BIN/OD_stop
    if [ $? != 0 ]; then
        echo "[IAPS]OD service couldn't be stopped"
        exit 1
    fi

    # JXM stop
    $JMX_BIN/isjmxstop
    if [ $? != 0 ]; then
        echo "[IAPS]JXM service couldn't be stopped"
        exit 1
    fi
fi

# ISAS Cloning
$ISAS_BIN/issethostinfo -h $hostname -i $ipaddress
if [ $? != 0 ]; then
    ERROR_MSG=$ERROR_MSG"[issethostinfo]"
    errflg=1
fi

# ISI Cloning
if [ "$ESI_HOME" = "" ] ; then
    ESI_HOME=/opt/FJSVesi
    export ESI_HOME
fi
if [ "$JAVA_HOME" = "" ] ; then
    JAVA_HOME=/opt/FJSVawjbk/jdk5
fi
TMP_CWD=`dirname $0`
TMP_DIR=`cd $TMP_CWD;pwd`
$JAVA_HOME/bin/java -jar $TMP_DIR/ISISetHostProperties.jar $hostname
if [ $? != 0 ] ; then
    ERROR_MSG=$ERROR_MSG"[ISISetHostProperties]"
    errflg=1
else
    /bin/chmod 660 /opt/FJSVesi/etc/def/properties/ESISystemConfig.properties
    GROUP=`/opt/FJSVesi/bin/esisetsecuritymode -l | /bin/cut -d':' -f2`
    if [ "$GROUP" != "" ] ; then
        /bin/chown root:$GROUP /opt/FJSVesi/etc/def/properties/ESISystemConfig.properties
    fi
fi


# error
if [ $errflg == 1 ] ; then
    echo "[ISI]Error has occurred :" $ERROR_MSG 1>&2
    exit 1
fi

# normal
    echo "[ISI]Setup has been finished normally" 1>&2
    exit 0

